@@ -60,17 +60,6 @@ def minimize_reactions(original_reactions_to_run, added_reactions, modeldata, me
     # Combine old and new reactions
     return original_reactions_to_run.union(reqd_additional)
 
-def read_fn_roles(functional_roles_file, verbose=False):
-    """
-    Read the assigned functions from a file with a list of roles.
-    :param functional_roles_file: The file to read
-    :param verbose: more output
-    :return: a set of the roles
-    :rtype: set[str]
-    """
-
-    return PyFBA.parse.read_functional_roles(functional_roles_file, verbose)
-
 
 def read_assigned_functions(assf, verbose=False):
     """
@@ -371,7 +360,8 @@ def gapfill_from_roles():
     parser = argparse.ArgumentParser(description='Run Flux Balance Analysis on a set of gapfilled functional roles')
     group = parser.add_mutually_exclusive_group(required=True)
     group.add_argument('-r', '--roles', help='A list of functional roles in this genome, one per line')
-    group.add_argument('-f', '--functions', help='RAST assigned functions role (tab separated PEG/Functional Role)')
+    group.add_argument('-a', '--assigned_functions', help='RAST assigned functions role (tab separated PEG/Functional Role)')
+    group.add_argument('-f', '--features', help='PATRIC features.txt file (with 5 columns)')
     parser.add_argument('-o', '--output', help='file to save new reaction list to', required=True)
     parser.add_argument('-m', '--media', help='media name', required=True)
     parser.add_argument('-t', '--type', default='gramnegative',
@@ -383,9 +373,11 @@ def gapfill_from_roles():
 
     model_data = PyFBA.parse.model_seed.parse_model_seed_data(args.type)
     if args.roles:
-        roles = read_fn_roles(args.roles, args.verbose)
-    elif args.functions:
-        roles = read_assigned_functions(args.functions, args.verbose)
+        roles = PyFBA.parse.read_functional_roles(args.roles, args.verbose)
+    elif args.assigned_functions:
+        roles = read_assigned_functions(args.assigned_functions, args.verbose)
+    elif args.features:
+        roles = PyFBA.parse.read_features_file(args.features, args.verbose)
     else:
         sys.stderr.write("FATAL. Either a roles or functions file must be provided")
         sys.exit(1)
