@@ -12,16 +12,20 @@ args = parser.parse_args()
 
 compounds, reactions, enzymes = PyFBA.parse.compounds_reactions_enzymes('gramnegative')
 
+for c in compounds:
+    if c.name == args.c:
+        wanted = c
+        break
 
-generic = PyFBA.metabolism.Compound(args.c, '')
-if str(generic) in compounds:
+if str(wanted) in compounds:
     print("Reactions associated with generic compound {}:".format(args.c))
-    for r in compounds[str(generic)].reactions:
+    for r in compounds[str(wanted)].reactions:
         print(r)
 else:
-    sys.stderr.write("No compound like {} found\n".format(generic))
+    sys.stderr.write("No compound like {} found\n".format(wanted))
 
-intracellular = PyFBA.metabolism.Compound(args.c, 'c')
+intracellular = wanted
+intracellular.location = 'c'
 if str(intracellular) in  compounds:
     print("Reactions associated with the intracellular compound {}:".format(args.c))
     for r in compounds[str(intracellular)].reactions:
@@ -29,7 +33,8 @@ if str(intracellular) in  compounds:
 else:
     sys.stderr.write("No compound like {} found\n".format(intracellular))
 
-extracellular = PyFBA.metabolism.Compound(args.c, 'e')
+extracellular = wanted
+extracellular.location = 'e'
 if str(extracellular) in compounds:
     print("Reactions associated with the extracellular compound {}:".format(args.c))
     for r in compounds[str(extracellular)].reactions:
